opendc
=====

An entire datacenters worth of infrastructure running atop Kubernetes.

Website http://opendatacentre.io

Documentation http://docs.opendatacentre.io

Presentation https://www.slideshare.net/DesDrury/open-datacentre
